#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-v3Lv3oGrFNF7Tor093kUX
key:                  graphite-0.10.0.1-v3Lv3oGrFNF7Tor093kUX
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  5b68160c079cdf49fc7fcf278821fe0f
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-v3Lv3oGrFNF7Tor093kUX
depends:
    QuickCheck-2.15.0.1-E7cfXUQH5j0nG0YUtYjiD base-4.18.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-DYBoycNtuB1BwS0P9b19aj
    containers-0.6.7 deepseq-1.4.8.1
    graphviz-2999.20.2.1-KOIgcsYAnuWF9ISrZOpSbZ
    hashable-1.4.7.0-8qGpYVybfmaKH8giGSMaAG process-1.6.19.0
    random-1.2.1.3-Fpl3dUa1VuLH6jaWIu29Ly text-2.0.2
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY
    vector-0.13.2.0-AWRowWUrdYO1choGzrrEgg

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

